@@ -10,9 +10,9 @@ sampP = function(tree, cell.line) {
         }
         P = round(P, 3)
         if (ncol(P) == 1) {
-            P[nrow(P), ] = 1 - colSums(as.matrix(P[1:(nrow(P) - 1), ]))
+            P[nrow(P), ] = 1 - colSums(as.matrix(P[1:(nrow(P) - 1), , drop = FALSE]))
         } else {
-            P[nrow(P), ] = 1 - colSums(P[1:(nrow(P) - 1), ])
+            P[nrow(P), ] = 1 - colSums(P[1:(nrow(P) - 1), , drop = FALSE])
         }
     } else if (cell.line == FALSE) {
         P = tree$P
@@ -25,10 +25,9 @@ sampP = function(tree, cell.line) {
         }
         P = round(P, 3)
         if (ncol(P) == 1) {
-            P[nrow(P), ] = 1 - colSums(as.matrix(P[1:(nrow(P) - 1), 
-                ]))
+            P[nrow(P), ] = 1 - colSums(as.matrix(P[1:(nrow(P) - 1), , drop = FALSE]))
         } else {
-            P[nrow(P), ] = 1 - colSums(P[1:(nrow(P) - 1), ])
+            P[nrow(P), ] = 1 - colSums(P[1:(nrow(P) - 1), , drop = FALSE])
         }
     }
     return(P)
